@@ -485,23 +485,25 @@ sub output_wrap_property($$$$$$)
     my $name_underscored = $name;
     $name_underscored =~ s/-/_/g;
 
-    my $str = sprintf("_PROPERTY_PROXY(%s,%s,%s,%s)dnl\n",
+    my $str = sprintf("_PROPERTY_PROXY(%s,%s,%s,%s,%s)dnl\n",
       $name,
       $name_underscored,
       $cpp_type,
-      $proxy_suffix
+      $proxy_suffix,
+      $objProperty->get_docs()
     );
     $self->append($str);
     $self->append("\n");
 
-    # If the property is not already read-only, then add a second const accessor for a read-only propertyproxy:
-    if($proxy_suffix ne "_ReadOnly")
+    # If the property is not already read-only, and the property can be read, then add a second const accessor for a read-only propertyproxy:
+    if( ($proxy_suffix ne "_ReadOnly") && ($objProperty->get_readable()) )
     {
-      my $str = sprintf("_PROPERTY_PROXY(%s,%s,%s,%s)dnl\n",
+      my $str = sprintf("_PROPERTY_PROXY(%s,%s,%s,%s,%s)dnl\n",
         $name,
         $name_underscored,
         $cpp_type,
-        "_ReadOnly"
+        "_ReadOnly",
+        $objProperty->get_docs()
       );
       $self->append($str);
     }
